@@ -41,7 +41,7 @@ class ChooseStripNumDialog : public QDialog
         ChooseStripNumDialog(QWidget *parent, int current, int min, int max)
             : QDialog( parent )
         {
-            setWindowTitle(i18n("Go to Strip"));
+            setWindowTitle(i18nc("@title:window", "Go to Strip"));
 
             QVBoxLayout *topLayout = new QVBoxLayout(this);
             topLayout->setMargin(0);
@@ -49,7 +49,7 @@ class ChooseStripNumDialog : public QDialog
             numInput->setRange(min, max);
             numInput->setValue(current);
 
-            QLabel *label = new QLabel(i18n("&Strip Number:"), this);
+            QLabel *label = new QLabel(i18nc("@label:spinbox", "&Strip number:"), this);
             label->setBuddy(numInput);
             topLayout->addWidget(label);
             topLayout->addWidget(numInput) ;
@@ -95,7 +95,7 @@ StripSelector *StripSelectorFactory::create(IdentifierType type)
             return new StringStripSelector();
     }
 
-    return 0;
+    return nullptr;
 }
 
 
@@ -111,7 +111,8 @@ StringStripSelector::~StringStripSelector()
 void StringStripSelector::select(const ComicData &currentStrip)
 {
     bool ok;
-    const QString strip = QInputDialog::getText(0, i18n("Go to Strip"), i18n("Strip identifier:"), QLineEdit::Normal,
+    const QString strip = QInputDialog::getText(nullptr, i18nc("@title:window", "Go to Strip"),
+                                                i18nc("@label:textbox", "Strip identifier:"), QLineEdit::Normal,
                                                  currentStrip.current(), &ok);
     if (ok) {
         emit stripChosen(strip);
@@ -130,7 +131,7 @@ NumberStripSelector::~NumberStripSelector()
 
 void NumberStripSelector::select(const ComicData &currentStrip)
 {
-    QScopedPointer<ChooseStripNumDialog> pageDialog(new ChooseStripNumDialog(0, currentStrip.current().toInt(),
+    QScopedPointer<ChooseStripNumDialog> pageDialog(new ChooseStripNumDialog(nullptr, currentStrip.current().toInt(),
                                                     currentStrip.firstStripNum(), currentStrip.maxStripNum()));
     if (pageDialog->exec() == QDialog::Accepted) {
         emit stripChosen(QString::number(pageDialog->getStripNumber()));
@@ -154,7 +155,7 @@ void DateStripSelector::select(const ComicData &currentStrip)
     KDatePicker *calendar = new KDatePicker;
     calendar->setAttribute(Qt::WA_DeleteOnClose);//to have destroyed emitted upon closing
     calendar->setMinimumSize(calendar->sizeHint());
-    calendar->setDate(QDate::fromString(currentStrip.current(), "yyyy-MM-dd"));
+    calendar->setDate(QDate::fromString(currentStrip.current(), QStringLiteral("yyyy-MM-dd")));
 
     connect(calendar, &KDatePicker::dateSelected, this, &DateStripSelector::slotChosenDay);
     connect(calendar, &KDatePicker::dateEntered, this, &DateStripSelector::slotChosenDay);
@@ -167,14 +168,11 @@ void DateStripSelector::select(const ComicData &currentStrip)
 void DateStripSelector::slotChosenDay(const QDate &date)
 {
     if (date <= QDate::currentDate()) {
-        QDate temp = QDate::fromString(mFirstIdentifierSuffix, "yyyy-MM-dd");
+        QDate temp = QDate::fromString(mFirstIdentifierSuffix, QStringLiteral("yyyy-MM-dd"));
         // only update if date >= first strip date, or if there is no first
         // strip date
         if (temp.isValid() || date >= temp) {
-            emit stripChosen(date.toString("yyyy-MM-dd"));
+            emit stripChosen(date.toString(QStringLiteral("yyyy-MM-dd")));
         }
     }
 }
-
-#include "moc_stripselector.cpp"
-#include "moc_stripselector_p.cpp"
